@@ -397,7 +397,7 @@ mpv_handle *MpvProxy::mpv_init()
             my_set_property(m_handle, "hwdec", "auto");
         }
 
-#if defined (__mips__) || defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64)
+#if defined (__mips__)
         if (!CompositingManager::get().hascard()) {
             qInfo() << "修改音视频同步模式";
             my_set_property(m_handle, "video-sync", "desync");
@@ -405,6 +405,13 @@ mpv_handle *MpvProxy::mpv_init()
         my_set_property(m_handle, "vo", "vdpau,gpu,x11");
         my_set_property(m_handle, "ao", "alsa");
         m_sInitVo = "vdpau,gpu,x11";
+#elif defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64)
+        if (!CompositingManager::get().hascard()) {
+            qInfo() << "修改音视频同步模式";
+            my_set_property(m_handle, "video-sync", "desync");
+        }
+        my_set_property(m_handle, "vo", "gpu,x11");
+        m_sInitVo = "gpu,x11";
 #elif defined (__sw_64__)
         //Synchronously modify the video output of the SW platform vdpau(powered by zhangfl)
         my_set_property(m_handle, "vo", "vdpau,gpu,x11");
@@ -465,7 +472,7 @@ mpv_handle *MpvProxy::mpv_init()
     //my_set_property(pHandle, "correct-pts", false);
     //my_set_property(pHandle, "fps", 30);
     my_set_property(pHandle, "panscan", 0);
-    my_set_property(pHandle, "volume-max", 100.0);
+    my_set_property(pHandle, "volume-max", 200.0);
     my_set_property(pHandle, "input-cursor", "no");
     my_set_property(pHandle, "cursor-autohide", "no");
     my_set_property(pHandle, "sub-auto", "fuzzy");
@@ -661,11 +668,13 @@ void MpvProxy::handle_mpv_events()
             // caused by seek or just playing
             break;
 
+#if MPV_CLIENT_API_VERSION < MPV_MAKE_VERSION(2,0)
         case MPV_EVENT_TRACKS_CHANGED:
             qInfo() << m_eventName(pEvent->event_id);
             updatePlayingMovieInfo();
             emit tracksChanged();
             break;
+#endif
 
         case MPV_EVENT_FILE_LOADED: {
             qInfo() << m_eventName(pEvent->event_id);
@@ -1015,8 +1024,8 @@ void MpvProxy::volumeDown()
 int MpvProxy::volume() const
 {
     int nActualVol = my_get_property(m_handle, "volume").toInt();
-    int nDispalyVol = static_cast<int>((nActualVol - 40) / 60.0 * 200.0);
-    return nDispalyVol;
+    int nDispalyVol = static_cast<int>((nActualVol - 40) / 60.0 * 100.0);
+    return nDispalyVol > 100 ? nActualVol : nDispalyVol;
 }
 
 int MpvProxy::videoRotation() const
@@ -1078,12 +1087,13 @@ void MpvProxy::refreshDecode()
             auto codec = currentInfo.mi.videoCodec();
             auto name = _file.fileName();
             isSoftCodec = codec.toLower().contains("mpeg2video") || codec.toLower().contains("wmv") || name.toLower().contains("wmv");
+#if !defined(_loongarch) && !defined(__loongarch__) && !defined(__loongarch64)
             //探测硬解码
             if(!isSoftCodec) {
                 isSoftCodec = !isSurportHardWareDecode(codec, currentInfo.mi.width, currentInfo.mi.height);
             }
+#endif
         }
-
         if (isSoftCodec) {
             qInfo() << "my_set_property hwdec no";
             my_set_property(m_handle, "hwdec", "no");
@@ -1370,7 +1380,9 @@ qint64 MpvProxy::nextBurstShootPoint()
 int MpvProxy::volumeCorrection(int displayVol)
 {
     int realVol = 0;
-    realVol = static_cast<int>((displayVol / 200.0) * 60.0 + 40);
+    if (displayVol > 100)
+        return displayVol;
+    realVol = static_cast<int>((displayVol / 100.0) * 60.0 + 40);
     return (realVol == 40 ? 0 : realVol);
 }
 
