@@ -42,6 +42,7 @@
 #include "dguiapplicationhelper.h"
 #include "filefilter.h"
 #include "qtplayer_proxy.h"
+#include "eventlogutils.h"
 
 #include <QPainterPath>
 
@@ -139,7 +140,9 @@ bool PlayerEngine::isPlayableFile(const QUrl &url)
     if (FileFilter::instance()->isMediaFile(url)) {
         return true;
     } else {    // 网络文件不提示
-        emit sigInvalidFile(QFileInfo(url.toString()).fileName());
+        if(url.isLocalFile()) {
+            emit sigInvalidFile(QFileInfo(url.toLocalFile()).fileName());
+        }
         return false;
     }
 }
@@ -156,9 +159,10 @@ bool PlayerEngine::isPlayableFile(const QString &name)
     }
 
     if (url.isLocalFile()) {   // 网络文件不提示
-        emit sigInvalidFile(QFileInfo(url.toString()).fileName());
+        emit sigInvalidFile(QFileInfo(url.toLocalFile()).fileName());
         return false;
     }
+    return  false;
 }
 
 bool PlayerEngine::isAudioFile(const QString &name)
@@ -535,7 +539,7 @@ void PlayerEngine::paintEvent(QPaintEvent *e)
         if (_state != Idle && m_bAudio) {
             p.fillRect(rect, QBrush(QColor(0, 0, 0)));
         } else {
-            QImage icon = utils::LoadHiDPIImage(":/resources/icons/light/init-splash.svg");
+            QImage icon = QIcon::fromTheme("deepin-movie").pixmap(130, 130).toImage();;
             QPixmap pix = QPixmap::fromImage(icon);
             QPointF pos = rect.center() - QPoint(pix.width() / 2, pix.height() / 2) / devicePixelRatioF();
 
@@ -570,6 +574,18 @@ void PlayerEngine::requestPlay(int id)
     } else {
         // TODO: delete and try next backend?
     }
+
+    QJsonObject obj{
+        {"tid", EventLogUtils::StartPlaying},
+        {"version", VERSION},
+        {"successful", true},
+        {"type", currFileIsAudio() ? "audio" : "video"},
+        {"origin", item.url.isLocalFile() ? "local" : "http"},
+        {"encapsulation_format", item.mi.fileType},
+        {"coding_format",  utils::videoIndex2str(item.mi.vCodecID)}
+    };
+
+    EventLogUtils::get().writeLogs(obj);
 }
 
 void PlayerEngine::savePlaybackPosition()
