@@ -1352,6 +1352,7 @@ void ToolboxProxy::initMember()
     m_pPaClose = nullptr;
 
     m_nClickTime = 0;
+    m_processAdd = 0.0;
 
     m_bMouseFlag = false;
     m_bMousePree = false;
@@ -2522,7 +2523,21 @@ void ToolboxProxy::updateProgress(int nValue)
 
     if (m_pProgBar_Widget->currentIndex() == 1) {              //进度条模式
 
-        int nCurrPos = m_pProgBar->value() + nValue * nDuration / m_pProgBar->width();
+        float value = nValue * nDuration / m_pProgBar->width();
+        int nCurrPos;
+        if (value > 1 || value < -1) {
+            nCurrPos = m_pProgBar->value() + value;
+        } else {
+            if (m_processAdd < 1.0 && m_processAdd > -1.0) {
+                m_processAdd += (float)(nValue * nDuration) / m_pProgBar->width();
+                qInfo() << m_processAdd;
+                return;
+            }
+            else {
+                nCurrPos = m_pProgBar->value() + m_processAdd;
+                m_processAdd = .0;
+            }
+        }
         if (!m_pProgBar->signalsBlocked()) {
             m_pProgBar->blockSignals(true);
         }
